@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module AMQ
   module Protocol
     TLS_PORT         = 5671
@@ -12,6 +14,7 @@ module AMQ
     PACK_UINT16_X2          = 'n2'.freeze
     PACK_UINT32             = 'N'.freeze
     PACK_UINT32_X2          = 'N2'.freeze
+    PACK_UINT64_BE          = 'Q>'.freeze
     PACK_INT64              = 'q'.freeze
     PACK_INT64_BE           = 'q>'.freeze
     PACK_UCHAR_UINT32       = 'CN'.freeze
